# Pymind

Pymind is a Python library for AI, supporting Numpy and Cupy. Pymindcorecupy is always fully up to date with pymindcore, dispite the version number differences.

## Installation

You can install Pymind using pip: pip install pymindcore-cupy.

## Usage

You import it, you call the class with your neural network size, and you're away! 

## License

This project is licensed under the CCO license.
